@@ -56,11 +56,13 @@ def run_lex(args=[], input=None, output=None):
     )
 
 
-def run_domparser(args=[], input=None, output=None, lexicon=None, valence=None):
+def run_domparser(args=[], input=None, output=None, lexicon=None, valence=None, mwe=None, ne=None):
     lexicon_input = "empty" if lexicon is None else b64encode(lexicon.encode()).decode()
     valence_input = "empty" if valence is None else b64encode(valence.encode()).decode()
+    mwe_input = "empty" if mwe is None else b64encode(mwe.encode()).decode()
+    ne_input = "empty" if ne is None else b64encode(ne.encode()).decode()
     return subprocess.Popen(
-        create_cmd(["docker", "run", "-i", DOCKER_IMAGE_NAME, "/root/domparser.sh", lexicon_input, valence_input] + args),
+        create_cmd(["docker", "run", "-i", DOCKER_IMAGE_NAME, "/root/domparser.sh", lexicon_input, valence_input, mwe_input, ne_input] + args),
         stdin=input,
         stdout=output,
         stderr=output,
@@ -174,7 +176,25 @@ class SubsyntaxResult():
 
 
 class Eniam():
-    def __init__(self, lexicon_keywords=None, lexicon=None, valence_names=None, valence=None):
+
+    def with_mwe(self, mwe):
+        output = []
+        for entity in mwe:
+            output.append(f"{entity[0]}\t{entity[1]}\t{entity[2]}")
+        self.mwe = "\n".join(output)
+        return self
+
+    def with_ne(self, ne):
+        output = []
+        for entity in ne:
+            output.append(f"{entity[0]}\t{entity[1]}")
+        self.ne = "\n".join(output)
+        return self
+
+    def __init__(self, lexicon_keywords=None, lexicon=None, valence_names=None, valence=None, mwe=None, ne=None):
+
+        self.mwe = None
+        self.ne = None
 
         lexicon_base_keywords = """
           infp np prepnp adjp ip cp ncp advp padvp
@@ -405,7 +425,7 @@ class Eniam():
         """
 
     def dom(self, input_text, silent=True):
-        p = run_domparser(["--no-sem", "--no-def-cat"], PIPE, PIPE, self.lexicon_content, self.valence_content)
+        p = run_domparser(["--no-sem", "--no-def-cat"], PIPE, PIPE, self.lexicon_content, self.valence_content, self.mwe, self.ne)
         q_out = Queue()
         q_err = Queue()
 
