@@ -373,4 +373,9 @@ inst = gram('inst')
 loc = gram('loc')
 postp = gram('postp')
 n = gram('n')
-sg = gram('sg')
\ No newline at end of file
+sg = gram('sg')
+
+
+pri = gram('pri')
+sec = gram('sec')
+ter = gram('ter')
\ No newline at end of file
